# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/adv-ml',
                'doc_host': 'https://Irad-Zehavi.github.io',
                'git_url': 'https://github.com/Irad-Zehavi/adv-ml',
                'lib_path': 'adv_ml'},
  'syms': { 'adv_ml.all': {},
            'adv_ml.backdoor': { 'adv_ml.backdoor.BackdoorAttack': ('Core/backdoor.html#backdoorattack', 'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.BackdoorAttack._asr_dl': ( 'Core/backdoor.html#backdoorattack._asr_dl',
                                                                             'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.BackdoorAttack.after_create': ( 'Core/backdoor.html#backdoorattack.after_create',
                                                                                  'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack': ('Core/backdoor.html#datapoisoningattack', 'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack.__init__': ( 'Core/backdoor.html#datapoisoningattack.__init__',
                                                                                   'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack._poison': ( 'Core/backdoor.html#datapoisoningattack._poison',
                                                                                  'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack._poison_train_dl': ( 'Core/backdoor.html#datapoisoningattack._poison_train_dl',
                                                                                           'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack._subset_to_poison': ( 'Core/backdoor.html#datapoisoningattack._subset_to_poison',
                                                                                            'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor.DataPoisoningAttack.after_create': ( 'Core/backdoor.html#datapoisoningattack.after_create',
                                                                                       'adv_ml/backdoor.py'),
                                 'adv_ml.backdoor._poisoned_dataset': ('Core/backdoor.html#_poisoned_dataset', 'adv_ml/backdoor.py')},
            'adv_ml.badnets': { 'adv_ml.badnets.BadNetsAttack': ('badnets.html#badnetsattack', 'adv_ml/badnets.py'),
                                'adv_ml.badnets.BadNetsAttack.__init__': ('badnets.html#badnetsattack.__init__', 'adv_ml/badnets.py'),
                                'adv_ml.badnets.BadNetsAttack._asr_dl': ('badnets.html#badnetsattack._asr_dl', 'adv_ml/badnets.py'),
                                'adv_ml.badnets.BadNetsAttack._insert_trigger': ( 'badnets.html#badnetsattack._insert_trigger',
                                                                                  'adv_ml/badnets.py'),
                                'adv_ml.badnets.BadNetsAttack._poison': ('badnets.html#badnetsattack._poison', 'adv_ml/badnets.py')},
            'adv_ml.evasion': { 'adv_ml.evasion.L2PGD': ('evasion.html#l2pgd', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.L2PGD.project_pert': ('evasion.html#l2pgd.project_pert', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.L2PGD.rand_init': ('evasion.html#l2pgd.rand_init', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.L2PGD.steepest_descent': ('evasion.html#l2pgd.steepest_descent', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.LinfPGD': ('evasion.html#linfpgd', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.LinfPGD.project_pert': ('evasion.html#linfpgd.project_pert', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.LinfPGD.rand_init': ('evasion.html#linfpgd.rand_init', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.LinfPGD.steepest_descent': ('evasion.html#linfpgd.steepest_descent', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback': ('evasion.html#pgdcallback', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.__init__': ('evasion.html#pgdcallback.__init__', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.after_batch': ('evasion.html#pgdcallback.after_batch', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.before_step': ('evasion.html#pgdcallback.before_step', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.clamp_pixel_values': ( 'evasion.html#pgdcallback.clamp_pixel_values',
                                                                                   'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.init_pert': ('evasion.html#pgdcallback.init_pert', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.project_pert': ('evasion.html#pgdcallback.project_pert', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.rand_init': ('evasion.html#pgdcallback.rand_init', 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.steepest_descent': ( 'evasion.html#pgdcallback.steepest_descent',
                                                                                 'adv_ml/evasion.py'),
                                'adv_ml.evasion.PGDCallback.suggest_lr': ('evasion.html#pgdcallback.suggest_lr', 'adv_ml/evasion.py'),
                                'adv_ml.evasion._batch_norm': ('evasion.html#_batch_norm', 'adv_ml/evasion.py'),
                                'adv_ml.evasion._batch_normalize': ('evasion.html#_batch_normalize', 'adv_ml/evasion.py'),
                                'adv_ml.evasion._random_unit_vector': ('evasion.html#_random_unit_vector', 'adv_ml/evasion.py')},
            'adv_ml.input_optimization': { 'adv_ml.input_optimization.InputOptimizer': ( 'Core/input_optimization.html#inputoptimizer',
                                                                                         'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.InputOptimizer.__init__': ( 'Core/input_optimization.html#inputoptimizer.__init__',
                                                                                                  'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.InputOptimizer._perturb': ( 'Core/input_optimization.html#inputoptimizer._perturb',
                                                                                                  'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.InputOptimizer.perturb': ( 'Core/input_optimization.html#inputoptimizer.perturb',
                                                                                                 'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.PerturbationCallback': ( 'Core/input_optimization.html#perturbationcallback',
                                                                                               'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.PerturbationCallback.init_pert': ( 'Core/input_optimization.html#perturbationcallback.init_pert',
                                                                                                         'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization.PerturbationCallback.suggest_lr': ( 'Core/input_optimization.html#perturbationcallback.suggest_lr',
                                                                                                          'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._Perturbation': ( 'Core/input_optimization.html#_perturbation',
                                                                                        'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._Perturbation.__init__': ( 'Core/input_optimization.html#_perturbation.__init__',
                                                                                                 'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._Perturbation.forward': ( 'Core/input_optimization.html#_perturbation.forward',
                                                                                                'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._TrainLoop': ( 'Core/input_optimization.html#_trainloop',
                                                                                     'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._TrainLoop.before_train': ( 'Core/input_optimization.html#_trainloop.before_train',
                                                                                                  'adv_ml/input_optimization.py'),
                                           'adv_ml.input_optimization._TrainLoop.before_validate': ( 'Core/input_optimization.html#_trainloop.before_validate',
                                                                                                     'adv_ml/input_optimization.py')}}}
